#
# spec file for package gedit
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _with_gi_python 1

Name:           gedit
Version:        3.20.2
Release:        1.34
Summary:        Small and lightweight UTF-8 text editor
License:        GPL-2.0+
Group:          Productivity/Text/Editors
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/gedit/3.20/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE gedit-desktop.patch -- Adds more MIME types.
Patch0:         gedit-desktop.patch
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.50.1
BuildRequires:  iso-codes-devel
BuildRequires:  python >= 3.2.3
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0) >= 2.44
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gspell-1) >= 0.2.5
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.19.0
BuildRequires:  pkgconfig(gtksourceview-3.0) >= 3.19.4
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.14.1
BuildRequires:  pkgconfig(libpeas-gtk-1.0) >= 1.14.1
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.5.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0.0
BuildRequires:  pkgconfig(sm) >= 1.0.0
BuildRequires:  pkgconfig(vapigen) >= 0.25.1
BuildRequires:  pkgconfig(x11)
Requires:       python3-cairo
%if %{_with_gi_python}
# See bnc#847114 - plugins generally depend on it
Requires:       python3-gedit
%endif
Requires:       python3-gobject
#bnc#910913 - plugin snippets depend on this package
Requires:       python3-gobject-cairo
Recommends:     %{name}-lang
Recommends:     iso-codes
Provides:       gedit2 = %{version}
Obsoletes:      gedit2 < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
Gedit is a small and lightweight UTF-8 text editor for the GNOME
environment.

%if %{_with_gi_python}
%package -n python3-gedit
Summary:        Python bindings for gedit
Group:          Development/Languages/Python

%description -n python3-gedit
Gedit is a small and lightweight UTF-8 text editor for the GNOME
environment.

This package provides the python bindings, based on gobject-introspection.
%endif

%package devel
Summary:        Small and lightweight UTF-8 text editor
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gtksourceview-devel
%if %{_with_gi_python}
Requires:       python3-gedit
%endif
Provides:       gedit2-devel = %{version}
Obsoletes:      gedit2-devel < %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
Gedit is a small and lightweight UTF-8 text editor for the GNOME
environment.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch0 -p0

%build
%configure \
    --enable-python
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name '*.la' -delete -print
%suse_update_desktop_file org.gnome.gedit
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post
/sbin/ldconfig
%desktop_database_post
%glib2_gsettings_schema_post

%postun
/sbin/ldconfig
%desktop_database_postun
%glib2_gsettings_schema_postun

%files
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING MAINTAINERS NEWS README
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/gedit
%{_bindir}/gnome-text-editor
%dir %{_datadir}/appdata
%{_datadir}/appdata/org.gnome.gedit.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.gnome.gedit.service
%{_datadir}/GConf/gsettings/gedit.convert
# %%{_datadir}/gedit/gir-1.0/ lives in -devel
%exclude %{_datadir}/gedit/gir-1.0/
%{_datadir}/gedit/
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.externaltools.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.filebrowser.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.filebrowser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.pythonconsole.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.time.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gedit.plugins.time.gschema.xml
%dir %{_libdir}/gedit/
%{_libdir}/gedit/libgedit.so
%{_libdir}/gedit/girepository-1.0/
%dir %{_libdir}/gedit/plugins/
# Explicitly list plugins so we know when we miss one
%{_libdir}/gedit/plugins/docinfo.plugin
%{_libdir}/gedit/plugins/libdocinfo.so
%{_libdir}/gedit/plugins/externaltools/
%{_libdir}/gedit/plugins/externaltools.plugin
%{_libdir}/gedit/plugins/filebrowser.plugin
%{_libdir}/gedit/plugins/libfilebrowser.so
%{_libdir}/gedit/plugins/modelines.plugin
%{_libdir}/gedit/plugins/libmodelines.so
%{_libdir}/gedit/plugins/pythonconsole/
%{_libdir}/gedit/plugins/pythonconsole.plugin
%{_libdir}/gedit/plugins/quickopen/
%{_libdir}/gedit/plugins/quickopen.plugin
%{_libdir}/gedit/plugins/snippets/
%{_libdir}/gedit/plugins/snippets.plugin
%{_libdir}/gedit/plugins/sort.plugin
%{_libdir}/gedit/plugins/libsort.so
%{_libdir}/gedit/plugins/spell.plugin
%{_libdir}/gedit/plugins/libspell.so
%{_libdir}/gedit/plugins/time.plugin
%{_libdir}/gedit/plugins/libtime.so
%if "%{_libdir}" != "%{_libexecdir}"
%dir %{_libexecdir}/gedit
%endif
%{_libexecdir}/gedit/gedit-bugreport.sh
%doc %{_mandir}/man1/gedit*
%{_datadir}/icons/hicolor/*/apps/*

%files lang -f %{name}.lang

%if %{_with_gi_python}
%files -n python3-gedit
%defattr(-,root,root)
%{python3_sitearch}/gi/overrides/Gedit*
%{python3_sitearch}/gi/overrides/__pycache__/Gedit*
%endif

%files devel
%defattr(-, root, root)
%doc %{_datadir}/gtk-doc/html/gedit/
%{_datadir}/gedit/gir-1.0/
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_datadir}/vala/vapi/gedit.deps
%{_datadir}/vala/vapi/gedit.vapi

%changelog
* Wed May 18 2016 fezhang@suse.com
- Fix group for gedit-devel to Development/Libraries/C and C++
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Sun May  8 2016 badshah400@gmail.com
- Update to version 3.20.2:
  + Misc bugfixes.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Fix group for gedit-devel: should be Productivity/Text/Editors
* Thu Mar 31 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Use a menubar only if gtk-shell-shows-menubar is set to true.
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Mon Mar 14 2016 zaitor@opensuse.org
- Update to version 3.19.5:
  + Spell plugin: adapt code for gspell API changes.
  + Save window size properly.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Spell plugin: adapt code for gspell API changes.
  + CSS updates.
  + AppData: add project_group and translation tags.
  + Various other code improvements and bug fixes.
  + Updated translations.
* Wed Jan 20 2016 dimstar@opensuse.org
- Update to version 3.19.3:
  + Rename to "Text Editor" in the .desktop file.
  + Use traditional menubar layout on XFCE, Unity, etc.
  + require the latest gspell for the spell plugin.
  + New Windows WiX installer.
  + CSS updates to track GTK+ changes.
  + Various minor code improvements and bug fixes.
  + Updated translations.
* Fri Jan 15 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Ship our own app icon.
  + Add shortcuts window.
  + Adapt code for gspell API changes.
  + Rename GeditViewHolder -> GeditViewCentering.
  + CloseConfirmationDialog: subclass GtkMessageDialog.
  + CSS updates to track GTK+ changes.
  + Various minor code improvements and bug fixes.
  + Updated translations.
- Add hicolor-icon-theme BuildRequires now gedit comes with own
  icons.
- Rebase gedit-desktop.patch.
* Fri Jan 15 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + Change default document title to "Untitled Document".
  + Port the spell plugin to gspell.
- Exchange enchant-devel for pkgconfig(gspell-1) BuildRequires
  following upstreams port.
* Fri Jan 15 2016 dimstar@opensuse.org
- Update to version 3.18.3:
  + Several crash fixes.
  + A few other more minor bug fixes.
  + Add kudos to appdata.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix performance problem with remote files in the open file
    selector.
  + Various minor code improvements and bug fixes.
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Make the Replace dialog resizable.
  + Various minor code improvements and bug fixes.
  + Updated translations.
* Tue Oct  6 2015 zaitor@opensuse.org
- Change gedit-devel Group: to include Development/ to silence a
  RPMLINT warning.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fix close confirmation dialog regression introduced in 3.17.92.
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Various minor code improvements and bug fixes.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Spell checking: fix performance problem and re-organize the
    code.
  + Move minimap settings in the preferences dialog.
  + CSS improvements.
  + Add a snippet generating RPM SPEC %%changelog line.
  + Various other code improvements and bug fixes.
  + Updated translations.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Lots of cleanups and code improvements to: the document
    handling code, file printing and the spell checking.
  + gtk-mac-integration support fix.
  + Updated translations.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add a menu to toggle the source map.
  + Fix print margins.
  + Fix the --wait options when passing a list of files.
  + Several cleanups and code improvements to the document handling
    code.
  + Various other bug fixes.
  + Updated translations.
* Sun Aug 16 2015 dimstar@opensuse.org
- Update to version 3.17.0:
  + Improve the Encodings dialog.
  + Add setting to display a grid pattern.
  + Various other bug fixes.
  + Updated translations.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Various bug fixes.
  + Updated translations.
* Fri May 15 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix gedit --wait when listing multiple files.
  + Various other bug fixes.
  + Updated translations.
* Sun Apr 12 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Improve error reporting when failing to load private lib.
  + Performance improvements for groups of text
    insertions/deletions.
  + Do not merge xml translation in gschema files.
  + Various other bug fixes.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Various bug fixes.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Rework some of the printing code.
  + Various bug fixes.
  + Updated translations.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Improved documentation.
  + Various bug fixes.
  + Updated translations.
* Wed Feb  4 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + Improved open document selector.
  + Start to rework the replace dialog.
  + Use the new color scheme chooser.
  + Updated translations.
* Wed Feb  4 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Various bug fixes.
  + Updated translations.
* Wed Jan 14 2015 tyang@suse.com
- Fix bnc#910913: enabling plugin snippets causes crash when close
  a tab. Add require for python3-gobject-cairo.
* Thu Dec  4 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + External tools plugin: fix document saving.
  + Various other bug fixes.
  + Updated translations.
* Sun Nov  9 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Increase default window size.
  + Various bug fixes.
  + Updated translations.
- Drop gedit-nobinenv.patch: Fix upstream (slightly different).
* Wed Sep 24 2014 dimstar@opensuse.org
- Add gedit-nobinenv.patch: do not add dependency to non-existing
  /bin/env.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Improvements on OSX port.
  + Improvements on Win32 port.
  + Misc bugfixes.
  + Updated translations.
- Add pkgconfig(vapigen) BuildRequires: Build vala support.
* Tue Aug 19 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Fix a segmentation fault when loading a file.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Set default value of create-backup-copy setting to false.
  + Misc improvements and bug fixes.
  + Updated translations.
* Tue Aug 12 2014 dimstar@opensuse.org
- Update to version 3.13.5:
  + Rework the headerbar again.
  + Fix opening files from nautilus.
  + Center the view in fullscreen mode.
  + Win32 improvements and new installer.
  + Misc bug fixes.
  + Updated translations.
* Tue Jul 29 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Update appdata file for new desktop file name.
  + Use automatic GTK menus.
  + Misc bug fixes.
  + Updated translations.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + File loading and saving based on a new API in GtkSourceView.
  + Include Adwaita theming.
  + New selector to open documents in the header bar.
  + Various improvements and bug fixes.
  + Some work to build gedit on Windows.
  + Updated translations.
- Rebased gedit-desktop.patch.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Zeitgeist plugin moved to the gedit-plugins module.
  + Some code clean-up in GeditTab and GeditDocument.
- Changes from version 3.13.1:
  + Statusbar: line/col popover menu.
  + Use GtkListBox for the style scheme list.
  + Make use of popover menu for the gear menu.
  + Make it work on Windows.
  + Add a gsettings for the last wrapping split -mode.
  + Misc bug fixes.
  + Updated translations.
- Remove traces of zeitgeist plugin:
  + Drop pkgconfig(zeitgeist-2.0) BuildRequires.
  + Remove gedit-plugin-zeitgeist subpackage (no obsoletes, as it
    will be built by gedit-plugins).
* Sun Jul  6 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Misc bug fixes.
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Many fixes to the snippets plugin.
  + Rework some of the internals in preparation to a new Windows
    release.
  + Change Uppercase shortcut to Ctrl+U to avoid conflict with
    Save All.
  + Add Ctrl+N shortcut for New Window.
  + Plug some minor memory leaks.
  + Misc bug fixes.
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Fix regression sorting recent files.
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Implement drag'n'drop for the documents panel.
  + Misc bug fixes.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Add keyboard shortcuts to change text case.
  + Readd bus message to add context menu items to the filebrowser.
  + Reopen last closed tab with ctrl+shift+T.
  + Rework fullscreen mode to use GtkRevealer.
  + Misc bug fixes.
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Even more work on the new UI (use popovers, CSD in dialogs and
    much more).
  + Reimplement the documents sidepane using GtkListBox.
  + Adapt plugins to the latest changes.
  + Misc bug fixes.
  + Updated translations.
* Thu Feb  6 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + More work on the new UI.
  + Finalize the new API to extend the menu from plugins.
  + Adapt plugins to the latest changes.
  + Restore command line handling that was broken in laste release.
  + Detect when network is not available and warn if using remote
    documents.
  + Add an fpaste tool to the external tools scripts.
  + Rewrite the build system with nonrecursive Makefiles.
  + Improvements in docs.
  + Misc bug fixes.
  + Updated translations.
* Thu Jan 23 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Refresh the main user interface, radically changing the user
    interacts with the UI.
  + Remove deprecated API.
  + Integrate change case plugin inside GtkSourceView directly.
  + Improvements in docs.
  + Misc bug fixes.
  + Updated translations.
* Thu Jan 23 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Implement XDS dnd support for GeditView and GeditWindow.
  + Documentation Improvements.
  + Style fixes.
  + Implement Move to New Tab Group.
  + Expand tabs and center tab labels.
  + Misc bugfixes and improvements.
  + Updated translations.
* Wed Jan 22 2014 dimstar@opensuse.org
- Update to version 3.10.4:
  + Fix a critical bug for the search.
  + Updated translations.
- Changes from version 3.10.3:
  + Misc bugfixes.
  + Updated translations.
* Wed Nov 13 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Misc bugfixes and improvements.
  + Updated translations.
* Tue Oct 22 2013 dimstar@opensuse.org
- Require python3-gedit if _with_gi_python is true: a bunch of
  plugins depend on the introspection bindings (bnc#847114).
  In theory, the plugins should depend on this, but there are many
  ways users could get them, resulting in frustration for not
  finding the right package.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Misc bugfixes and improvements.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Misc bugfixes and improvements.
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Some final tweaks to the search rework.
  + Misc bugfixes and improvements.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Misc bugfixes and improvements.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Implement regual expression search.
  + Misc bugfixes and improvements.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Use the GtkSourceView search and replace API.
  + Deprecate the gedit search and replace API.
  + Display the number of search occurrences and the current
    occurrence position in the search entry.
  + Fix tab groups.
  + Misc bugfixes and improvements.
  + Updated translations.
- Change _with_gi_python to 1: the python plugins are available
  again.
* Tue Jul  2 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Various bugfixes and improvements to the filebrowser and the
    external tools plugins.
  + Fix clicking on replace dialog buttons.
  + Misc bugfixes.
  + Updated translations.
- Remove --disable-scrollkeeper configure parameter, which has not
  been known since version 3.3.4, when the documentation
  infratructure changed from gnome-doc-utils to yelp-tools.
- Temporary disable python3-gedit subpackage, as building of the
  bindings is currently broken (define _with_gi_python 0).
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 3.9.2:
  + Many bugfixes and improvements to the filebrowser, quickopen
    and external tools plugins.
  + Misc bugfixes.
  + Updated translations.
* Tue Jun  4 2013 zaitor@opensuse.org
- Update to version 3.9.1:
  + Add new Highlight Mode dialog.
  + Allow shell quotes in commands from Run Command tool.
  + Use widget templates.
  + external tools:
  - Look in browser root for files in tool output.
  - Extend link parser to handle grep output.
  - Provide environment variable with file browser root.
  + Improvements in filebrowser.
  + Improvements in quickopen.
  + Improvements in docs.
  + Misc bugfixes.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Many bugfixes to the external tools, snippets and quickopen
    plugins,
  + Make preferences dialog resizable.
  + Rework how some settings are applied to documents.
  + Use GtkRGBA for text tags.
  + Misc Bugfixes.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Port zeitgeist plugin to use libzeitgeist2.
  + Improvements in docs.
  + Misc bugfixes.
  + Updated translations.
- Replace pkgconfig(zeitgeist-1.0) BuildRequires with
  pkgconfig(zeitgeist-2.0), following upstreams port to
  Zeitgeist 2.0.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Improvements in docs.
  + Misc bufixes.
  + Updated translations.
* Wed Mar 20 2013 dimstar@opensuse.org
- Update to version 3.7.6:
  + Improvements in docs.
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 11 2013 dimstar@opensuse.org
- Replace python-gobject Requires with python3-requires.
- Add python3-cairo requires: snippets/documents.py imports cairo.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated mallard snippets.
  + Improvements in docs.
  + Misc bugfixes.
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Use revealer to animate the search bar and the notification
    bars
  + Several fixes in snippets.
  + Improvements in docs.
  + Misc bugfixes.
  + Updated translations.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Application menu.
  + Misc bugfixes.
- Changes from version 3.7.2:
  + Port to GtkApplication.
  + Lots of improvements in docs.
  + Misc bugfixes.
  + Updated translations.
- Add pkgconfig(gio-2.0) and pkgconfig(libpeas-1.0) BuildRequires
  so they can be versioned.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + Port to python 3.
  + Misc bugfixes.
  + Updated translations.
- Add python BuildRequires so we can version it. Note: As the
  BuildRequires is python >= 3.2.3, this currently pulls in
  python3, which is in fact exactly what we want.
- Drop .desktop fixup hack: fixed upstream.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Misc bugfixes.
  + Updated translations.
- Remove the hack in %%setup to fixup the .desktop file: fixed
  upstream.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + File Browser side panel improvements.
  + Fix print preview in landscape mode.
  + Misc bugfixes.
  + Updated translations.
- Fixup .desktop file: add trailing semicolon to keywords.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Handle a command line specifying a big line number
  + Extensive snippet collection for docbook
  + Misc bugfixes
  + Updated translations.
* Fri Aug 31 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Improvements in snippets plugin
  + Use autoreconf instead gnome-autogen
  + Misc bugfixes
  + Updated translations.
* Sat Jul 21 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Improved html snippets
  + Misc bugfixes
  + Updated translations.
* Fri May 25 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + Misc bugfixes
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Misc bugfixes
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.8:
  + Misc bugfixes.
  + Updated translations.
- Rebase gedit-desktop.patch.
* Tue Mar  6 2012 dimstar@opensuse.org
- Update to version 3.3.7:
  + Add support for fdo desktop action spec.
  + Misc bugfixes.
- Rebase gedit-desktop.patch.
* Mon Mar  5 2012 dimstar@opensuse.org
- Update to version 3.3.6:
  + Fix the "time" plugin
  + Misc bugfixes
  + Updated translations.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Less clutter search popup
  + Use GResources
  + Misc bugfixes
  + Updated translations.
- Add pkgconfig(gtk+-3.0) and pkgconfig(libxml-2.0) BuildRequires
  to be able to require a minimum version.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Fix many memory leaks
  + Use Yelp Tools for docs generation
  + Docs updates
  + Misc bugfixes
  + Updated translations.
- Change gnome-doc-utils-devel BuildRequires to yelp-tools,
  following the build system change for user documentation.
- Manually list the translated help documents as %%find_lang doesn't
  support the new XDG help system yet.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(ice), pkgconfig(sm) and pkgconfig(x11)
  BuildRequires: they used to be pulled in by something else, but
  the relayout of xorg-x11 packages changed that.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Bring the OSX port up to date
  + Start fixing the Win32 port
  + Some minor UI improvements, some css styling is now in the
    Adwaita theme
  + Misc bugfixes
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add pkgconfig(zeitgeist-1.0) BuildRequires to build the zeitgeist
  plugin, that we missed before.
- Create a plugin-zeitgeist subpackage for the zeitgeist plugin, to
  avoid a dependency on zeitgeist from the main gedit package.
* Sun Jan  8 2012 dimstar@opensuse.org
- Update to version 3.3.2:
  + More docs awesome
  + Port snippets and external tools managers to GtkGrid
  + Fix crashes when exiting with new gtk+
  + Improvements in filebrowser plugin
  + Symbolic icons for close buttons
  + Misc bugfixes
  + Updated translations.
* Mon Dec 19 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Sidebar style for the panel
  + Remove outdated tool to generate a plugin skeleton
  + Clear the tools accel entry on backspace
  + Make restoring default print fonts actually work
  + Move to GtkGrid
  + Remove explicit gthread initialization
  + More docs awesome
  + Various other code changes
  + Updated translations.
* Thu Dec  8 2011 dimstar@opensuse.org
- Update to version 3.2.5:
  + Misc bugfixes.
- Changes from version 3.2.4:
  + Misc bugfixes.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Nov 16 2011 dimstar@opensuse.org
- Update to version 3.2.3:
  + Fix crash when dropping file in gedit with snippets plugin
    active.
  + Misc bugfixes.
  + Updated translations.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + More help awesome
  + Misc bugfixes
  + Updated translations.
* Mon Oct 17 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + More help awesome
  + Use GtkGrid in the replace dialog.
  + Misc bugfixes
  + Updated translations.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Recommends since the iso-codes data is used at
  runtime, but only in a plugin (so no Requires).
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Misc bugfixes
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.6:
  + Misc bugfixes
  + More documentation
  + Updated translations.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.5:
  + Update snippet for mallard
  + Update the quickopen dialog to look more GNOMEish 3
  + Use symbolic icons for the search popup.
  + Point to the right help in the dialogs
  + Updated translations.
* Mon Aug 22 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + Use css for the search popup
  + Use pygobject 3
  + More documentation
  + gboxed templates for snippets plugin
  + Misc bugfixes
  + Updated translations.
- Replace pkgconfig(pygobjct-2.0) BuildRequires with
  pkgconfig(pygobject-3.0).
* Thu Aug  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Misc bugfixes
  + Updated translations.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + Add markdown snippets
  + Fix slowdown on gedit
  + Update to use libpeas 1.1 API
  + New GNOME 3 like style for snippets and external tools
  + Misc bugfixes
  + Updated translations.
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Port to GtkOverlay
  + Fix single instance logic
  + Misc bugfixes
  + Updated translations.
* Tue May 31 2011 fcrozat@novell.com
- Update to version 3.0.4:
  + bgo#651068: fix use-after-free during incremental search.
  + bgo#627789: don't use both intltool and gettext rules.
  + Updated translations.
* Wed May 25 2011 dimstar@opensuse.org
- Update to version 3.0.3:
  + Misc bugfixes
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.2:
  + Misc bugfixes
  + Updated translations.
- Changes from version 3.0.1:
  + Various fixes in search popup
  + Style improvements
  + Misc bugfixes
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Misc bugfixes
  + Updated translations.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.11:
  + Resurrect the plugin message bus
  + More improvements in the new user help
  + Misc bugfixes
  + Updated translations.
- Changes from version 2.91.10:
  + More improvements in the new user help
  + Misc bugfixes
- Changes from version 2.91.9:
  + More improvements in the new user help
  + Reactivate external tools and snippets plugins
  + Misc bugfixes
- Changes from version 2.91.8:
  + Help has been ported to mallard format
  + Improvements in the overlay
  + Misc bugfixes
- Changes from version 2.91.7:
  + Improvements in the overlay
  + Misc bugfixes
- Changes from version 2.91.6:
  + Fix encoding conversion
  + Add invalid char support
  + More plugins ported to pygobject
  + Misc bugfixes
- Changes from version 2.91.5:
  + Misc bugfixes
- Changes from version 2.91.4:
  + Port snippets plugin to libpeas/gtk3
  + Misc bugfixes
- Changes from version 2.91.3:
  + Misc bugfixes
- Changes from version 2.91.2:
  + Fix conversion of line endings when loading a file
  + Update to the latest Gtk3 api changes
  + Move the taglist plugin to the gedit-plugins package
  + Misc bugfixes
- Changes from version 2.91.1:
  + Use native GtkNotebook DnD implementation
  + Update to the latest Gtk3 api changes
  + Misc bugfixes
- Changes from version 2.91.0:
  + New reworked search dialog
  + Added mallard snippets
  + Updated translations.
- Changes from version 2.90.0:
  + Add GSettings migration file
  + Misc bugfixes
- Drop BuildRequires: gconf2-devel (move to GSettings),
  python-devel, python-gtk-devel, python-gtksourceview-devel (move
  to libpeas-based plugins).
- Add new pkgconfig() BuildRequires: libpeas-gtk-1.0,
  gsettings-desktop-schemas, libsoup-2.4.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gtksourceview-devel, python-gobject2-devel.
  + New ones: gtksourceview-3.0, pygobject-2.0.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Replace python-gnome, python-gobject2, python-gtk,
  python-gtksourceview Requires with just a python-gobject Requires
  thanks to introspection-based python binding.
- Change Obsoletes for gedit-doc to be strict (< instead of <=) now
  that we have a new version.
- Add /sbin/ldconfig to %%post/%%postun as there is now a (private)
  library installed by the package.
* Fri Feb 18 2011 gber@opensuse.org
- modified gedit-desktop.patch in order claim support for
  additional MIME types
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Remove 2.x references in summaries and descriptions.
- Drop doc subpackage as it contained developer doc that should be
  in the devel subpackage.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.30.4:
  + Add mallard snippets
  + Updated translations.
* Fri Jul 16 2010 vuntz@opensuse.org
- Update to version 2.30.3:
  + Misc bugfixes
  + Updated translations.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.2:
  + Fix cut and paste typo that broke syntax detection
- Changes from version 2.30.1:
  + Properly handle encoding conversion errors when saving
  + New logo
  + Misc bugfixes
  + Updated translations.
* Fri Apr  2 2010 vuntz@opensuse.org
- Remove libglade2-devel, libgnomeprintui-devel, libgnomeui-devel
  Requires from devel package.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Fix a crash in the new file saving code
  + Misc bugfixes
  + Updated translations.
* Mon Mar 15 2010 dimstar@opensuse.org
- Update to 2.29.9:
  + Fix a file corruption bug in the new file saving code
  + Misc bugfixes
  + Updated translations.
- Run spec-cleaner on gedit.spec.
* Wed Mar  3 2010 dimstar@opensuse.org
- Update to version 2.29.8:
  + Rework encoding validation
  + Misc bugfixes
  + Updated translations.
* Thu Feb 25 2010 dimstar@opensuse.org
- Update to version 2.29.7:
  + Misc bugfixes
  + Many string fixes
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + Add "Open" to the filebrowser context menu
  + Add option to ignore a version until the next is released in
    the checkupdate plugin
  + Misc bugfixes
  + Updated translations.
- Fix self-obsoletion of gedit2, gedit2-devel.
- Change group to Productivity/Text/Editors to fix rpmlint warning.
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Rework file saving and file loading to always use gio and take
    advantage of gio stream converters to perform encoding
    conversion and manage line terminators
  + Experimental python support on win32
  + Misc bugfixes
  + Translation updates
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.4:
  + Several refactorings
  + Don't check words that are marked no-spell-check
  + Tools outputpanel refactored
  + Added support for platform specific tools
  + Improved menu integration and several fixes on OS X
  + Add xslt and html snippets
  + Remember autospell per document
  + Misc bugfixes
  + Translation updates
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Use gio metadata system
  + Misc bugfixes
  + Updated translations.
- Changes from version 2.29.2:
  + Order hidden files after normal files on filebrowser
  + Removed indent plugin, this is now supported by gtksourceview
  + Implemented file open support on OS X
  + Fixed OS X native vs X11 built
  + Basic mac OS X integration
  + Use GtkSpinner instead of GeditSpinner
  + Misc bugfixes
  + Updated translations.
- Update the way we remove the la locale for old versions of
  openSUSE.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + Use the new completion framework in the snippets plugin
  + Misc bugfixes
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Misc bugfixes
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.6:
  + Misc bugfixes
  + Updated translations.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 2.27.5:
  + Misc bugfixes
  + Updated translations.
* Wed Aug 12 2009 captain.magnus@opensuse.org
- Update to version 2.27.4:
  + Misc bugfixes
  + Updated translations
* Tue Jul 28 2009 lmedinas@gmail.com
- Update to version 2.27.3:
  + Misc bugfixes
  + Updated translations
* Mon Jul 20 2009 vuntz@novell.com
- Also package libexecdir in addition to libdir in the file list to
  fix build.
* Mon Jun 22 2009 dominique-obs@leuenberger.net
- Update to version 2.27.2:
  + New Check Update plugin (win32 and mac only)
  + Remember the search dialog position
  + Do not append the final endline for empty files
  + Mac osx dmg package
  + Misc bugfixes
  + Updated translations.
- Add defattr() to the -lang sub-package to eliminate a lint false
  positive.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Remove the mmap document loader
  + Remove open location dialog and sample plugin
  + Added public API for document saving
  + Put external tools in a submenu
  + Added language support for external tools
  + Implemented asynchronous reading and writing on external tools
  + Add Quick Open plugin
  + Misc bugfixes
  + Updated translations.
- Do not package omf files twice.
* Mon May 18 2009 vuntz@novell.com
- Update to version 2.26.2:
  + Misc bugfixes
  + Updated translations.
- Stop having the main package provide the existing devel package.
- Make the devel package require the main package.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Ensure plugins are resident modules
  + Add Fortran 95 snippets
  + Misc bugfixes
  + Updated translations.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Misc bugfixes
  + Translation updates
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.8:
  + Misc bugfixes
  + Translation updates
- Remove -fno-strict-aliasing from CFLAGS.
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 2.25.7:
  + Misc bugfixes
  + Translation updates
- Remove BuildRequires: docbook_4, gnome-common, gnutls-devel,
  indent, scrollkeeper
* Thu Feb  5 2009 vuntz@novell.com
- Remove gnome-python-desktop BuildRequires/Requires.
- Remove python-xml Requires.
- Update Url.
* Thu Feb  5 2009 lmedinas@gmail.com
- Update to version 2.25.6:
  + Misc bugfixes
  + Translation updates
* Sat Jan 31 2009 mboman@suse.de
- Update to version 2.25.5:
  + Add Fullscreen Mode
  + Add a configuration dialog for the python console
  + Rescan plugins when opening the preference dialog
  + Misc bugfixes
  + Translation updates
- Remove gedit-return-fix.patch. Fixed upstream
* Mon Jan 26 2009 vuntz@novell.com
- On openSUSE <= 11.1, exclude locales unknown to the system.
* Fri Jan 23 2009 vuntz@novell.com
- Update gedit-desktop.patch to not uselessly change the icon.
- Remove some old BuildRequires.
- Minor cleanups.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.25.4:
  + Add quick syntax highlightig and tab width selection in the statusbar
  + More work on the internal bus system
  + Bugfixes and features for the snippets plugin
  + Parse syntax highlighting language from modelines
  + Misc bugfixes
  + Translation updates
* Wed Dec 31 2008 mboman@suse.de
- Update to version 2.25.3:
  + Win32 port with installer
  + Internal bus system to allow plugin intercomminication
  + Use GtkSourceView to detect language highlighting
  + Misc bugfixes
  + Translation updates
- Added gedit-return-fix.patch to fix a missing return.
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.25.2:
  + Fixes to the new plugin system
  + Rework the plugin system to have loaders as shared objects
  + Fix build on OSX
  + Fix icon lookup in the filebrowser plugin
  + Allow to move to a line relative to the current line
  + Misc bugfixes
  + Fix performance problem with large dirs in the filebrowser
    plugin
  + Translation updates
* Mon Nov  3 2008 maw@suse.de
- Build with python support again (bnc#439456).
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates
* Tue Sep 16 2008 vuntz@novell.com
- Update to version 2.23.93:
  + Revert a workaround for a gvfs bug that has now been fixed
  + Updated translations
* Fri Sep 12 2008 maw@suse.de
- Update to version 2.23.92:
  + Bugfixes related to the GIO migration
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Misc bugfixes
  + Updated translations.
* Fri Aug 29 2008 maw@suse.de
- Update to version 2.23.90:
  + Misc bugfixes related to the GIO migration
  + Updated translations.
* Fri Aug 15 2008 maw@suse.de
- Remove spurious requirements from the -doc subpackage.
* Tue Jul  1 2008 maw@suse.de
- Fix up icon symlinks.
* Sat Jun 21 2008 maw@suse.de
- Update to version 2.23.1:
  + The filebrowser plugin now users gio/gvfs
  + Initial work on porting gedit's internals to gio/gvfs
  + Python plugin core reworking
  + Updated translations.
* Thu May  8 2008 rodrigo@suse.de
- Tag patches
* Thu Apr 24 2008 maw@suse.de
- Require python-gtksourceview (bnc#337396).
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1:
  + Make C-d delete the current line
  + Misc. bugfixes
  + Updated translations.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Misc bugfixes
  + Updated translations.
* Thu Mar 13 2008 sbrabec@suse.cz
- Removed obsolete docinfo activation patch, now part of
  /apps/gedit-2/plugins/active-plugins.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.2:
  + Misc bugfixes
  + Updated translations.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.1:
  + Reimplemented printing using GtkPrint
  + Improvements to the plugin system
  + Handle viewports as well as workspaces
  + Updated translations.
* Fri Jan 25 2008 maw@suse.de
- Update to version 2.20.4:
  + Fix crash with invalid taglist file in taglist plugin
  + Fix slash-escaping in the find dialog history
  + Support .hidden file in the file browser plugin
  + Bugfixes to the snippet plugin
  + Fix tools loading in External Tools plugin
  + Fix crash when gtksourceview doesn't find any highlighting
    file
  + Properly preserve file permissions and ownership when saving
  + Properly detect the current display viewport, so that
    launching logic works properly on Compiz
  + Misc bugfixes
  + Updated translations.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.20.0:
  + Updated translations
- This release requires gtksourceview 2.0.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.91:
- Escape slashes when selecting text to search (Paolo Maggi)
- Support indent-width setting in modeline (Paolo Borelli)
- Adapt to the latest GtkSourceView changes (Paolo M., Paolo B.)
- User Interface to install and uninstall style schemes (Paolo Maggi)
- Make search match color customizable in the style scheme (Paolo M.)
- Tooltips on the document list and tag list (Alexandre Mazari)
- Misc bugfixes
- Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.3:
  + Port to gtksourceview 2
  + Remove Syntax Highlighting configuration from the preference
    dialog
  + Many improvements and fixes to the snippets plugin
  + Add a Document::save signal to notify the start of the saving
    operation
  + Adapt to latest GtkSourceView API changes
  + Add a gconf preference for smart-home-end
  + Fix external tool saving bug
  + Fixes weird focus behavior in the search/replace dialog
  + Make Ctrl+P work while print-previewing
  + Improve 'Build' external tool
  + Avoid having an always-running timeout, uses power
  + Don't fail when we cannot change rights on the backup file if
    it was not needed
  + Misc bugfixes
  + Updated translations
- Use %%fdupes.
* Mon Jul  9 2007 maw@suse.de
- Update to version 2.18.1
- Compress the tags plugin data
- Fix reversion of empty files, and other misc. bug files
- Updated translations.
* Thu May 10 2007 pgajdos@suse.cz
- removed
  - gnome-icon-theme and
  - hicolor-icon-theme
  from Requires and BuildRequires [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Tue Apr  3 2007 maw@suse.de
- Use a valid Icon directive in gedit.desktop.in.in.
* Mon Apr  2 2007 maw@suse.de
- Update to version 2.18.0
- Fix .desktop files
- b.g.o 413030, 412627, 407374, 407536, 354046, 403140, 401219,
  346598, 398343, 319950, 352959, 357529, and 371188
- Remove upstreamed gedit-autodetect-utf-16.patch
- Buildrequire notification-daemon.
* Mon Mar 12 2007 jhargadon@suse.de
- added gtk-doc to BuildRequires
* Wed Jan 17 2007 sbrabec@suse.cz
- Removed obsolete scrollkeeper directory (#230786).
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov 14 2006 jhargadon@suse.de
- made changes to the BuildRequires and Requires to enable python
  plugins.  defect #220820
* Fri Oct 13 2006 danw@suse.de
- Remove dead patches. Update and reenable gedit-autodetect-utf-16.patch
- Update for gnome-doc-utils-devel
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Remember the active page in the side and bottom panes
- Fix spinner with some themes
- Some fixes to the file saving code
- Filebrowser plugin fixes
- translation updates
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- Filebrowser plugin fixes
- Manual now covers basic usage of the file browser plugin
- New and updated translations
- Use proper preference when a modeline is changed
- Ensure correct lifecycle of objects in python plugins
- Proper error handling for remote file save
- Improve save on close for read-only files
- Handle remote zero length files correctly
- Make sure the document is editable after printing
- Consider the mime-type hierarchy to choose the syntax highlighting
- Initialize gnome authentication manager before plugins
- Misc improvements and bugfixes
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.8
- Update documentation
- Drop executable permissions from backup files
- Support for UTF-16LE, UTF-16BE and UTF-32
- Fix translations of some plugins
- Plug some memory leaks
- Fix another crash in GtkRecents code
- Misc improvements and bugfixes
- New and updated translations
- Preserve xattrs when saving
- Fix autospell menu item state
- Fix crash in GtkRecents code
- Misc improvements and bugfixes
* Tue Aug 22 2006 jhargadon@suse.de
- update to version 2.15.6
- Use GtkRecent for recent files support
- Raise the existing document when reopening a file
- File browser plugin bugfixes
- Misc improvements and bugfixes
* Thu Aug 10 2006 jhargadon@suse.de
- update to version 2.15.4
- Bindings for gedit_commands_* API for plugins
- Small snippets bugfixes
- Small fixes to the search/replace dialog/menu
- Fix cropped close buttons
- Added global lockdown functionality
- New gedit_commands_* API for plugins
- Snippets support for space indentation
- gtk-doc enabled Plugin API documentation
- Next/Previous menu items
- C/Python plugin skeleton generator
- Snippets plugin enhancements and fixes
- Fix Spellchecker to work with Arabic
- New layout for Plugin Manager
- Add support for custom plugin icons
- Snippets plugin enhancements and fixes
- Python bindings: gedit.utils functions and API cleanup
- Improve plugin selection UI
- Improvements and bugfixes to the snippets plugin
- do not open a new GdkDisplay for every window
- Fix launching on multihead systems
- Snippets plugin improvements
- Fix the python console history
- Fix vim and kate modelines parsing
- Fix the spell checking plugin
- Make the tags plugin load files lazily to improve startup time
* Thu Jun 29 2006 sbrabec@suse.cz
- Fixed Norwegian translation update (#116777#12).
* Mon Jun 26 2006 sbrabec@suse.cz
- Fixed false UTF-16 detection.
* Thu Jun 15 2006 dave@suse.de
- Fix a problem with the save backport (bnc #181897)
* Wed May 17 2006 dave@suse.de
- Backport some gnome-vfs saving code from 2.14 (bnc #168187)
* Tue May  9 2006 danw@suse.de
- Don't crash if one of the recently-used files has an unparsable
  URL. #173887
* Fri Apr  7 2006 sbrabec@suse.cz
- Declare MIME support for more plain text formats to compete with
  Emacs.
* Wed Apr  5 2006 joeshaw@suse.de
- Add a patch to autodetect UTF-16.  (bnc #116777)
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Feb  1 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added gnome-text-editor symlink to filelist
* Wed Oct 12 2005 gekker@suse.de
- Update to version 2.12.1
* Mon Sep  5 2005 mmj@suse.de
- Update to version 2.12.0 (GNOME 2.12)
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.92
* Fri Aug 19 2005 sreeves@suse.de
- gedit-goto-line.patch to fix bugzilla.novell.com defect#6582
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.91
* Mon Jun 13 2005 sbrabec@suse.cz
- Updated to version 2.10.3 (#90339, CAN-2005-1686).
- Build spell plugin.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Thu Mar 10 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 2.9.7
- Add gedit-desktop.patch
- Add gnome-icon-theme to neededforbuild
* Thu Feb 10 2005 gekker@suse.de
- Update to version 2.9.6
* Tue Feb  8 2005 ro@suse.de
- added gnome-desktop to neededforbuild
* Mon Feb  7 2005 ro@suse.de
- added gnome-menus to neededforbuild
* Tue Jan 25 2005 clahey@suse.de
- Update to version 2.9.5
* Fri Jan 21 2005 gekker@suse.de
- Use Rudi's improved 64-bit fix
* Fri Jan 21 2005 gekker@suse.de
- Fix the 64-bit build
* Thu Jan 20 2005 gekker@suse.de
- Update to version 2.9.4
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Oct 26 2004 mmj@suse.de
- Locale rename no to nb
* Tue Sep 21 2004 sbrabec@suse.cz
- Fixed devel dependences.
* Wed Aug 25 2004 clahey@suse.de
- Cache gedit docs and have gedit show up in khelpcenter.
* Wed Aug  4 2004 clahey@suse.de
- Added gedit-default-plugins patch from Robert.
* Wed May  5 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide nad obsolete gedit2-devel.
* Wed Mar 17 2004 sbrabec@suse.cz
- Fixed scrollkeeper calling conventions (#36215).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
- Fixed %%doc attributes (#33163).
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to gedit.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Wed Jan 21 2004 ro@suse.de
- fix pixmaps/Makefile.am
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.
* Thu Oct  9 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Sat Sep 20 2003 kukuk@suse.de
- Obsolete old gedit (solves file conflict)
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jul  4 2003 ro@suse.de
- fix find_lang usage
* Wed Jul  2 2003 hhetter@suse.de
- updated to version 2.2.2
- use find_lang
* Fri Jun 27 2003 ro@suse.de
- added directories to filelist
* Tue Jun 10 2003 ro@suse.de
- added unpackaged files to filelist
- remove .la files of plugins from buildroot
* Wed Feb 26 2003 hhetter@suse.de
- fix build (use omf.make) (#24336)
- fix filelist (#24336)
* Fri Feb  7 2003 hhetter@suse.de
- updated to version 2.2.0.1 [GNOME 2.2.0]
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.0
- filelist review
* Mon Jan 20 2003 ro@suse.de
- update to 2.1.6
* Tue Jan 14 2003 ro@suse.de
- added expat to neededforbuild
* Tue Nov 19 2002 hhetter@suse.de
- updated to version 2.0.6
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Fri Nov  8 2002 sbrabec@suse.cz
- Added --libdir to configure.
* Thu Nov  7 2002 hhetter@suse.de
- updated to version 2.0.5
- %%_lib fixes
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Fri Sep 13 2002 sf@suse.de
- fixed to work on 64-bit archs
  call of eel_read_entire_file() was with &gsize instead of int,
  sizeof(gsize) == sizeof(long)
* Thu Aug 22 2002 uli@suse.de
- fixed to build on lib64 archs
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Mon Aug 12 2002 ro@suse.de
- removed control-center from neededforbuild
* Sun Aug 11 2002 ro@suse.de
- added openssl-devel to neededforbuild
* Fri Aug  9 2002 hhetter@suse.de
- added openssl to neededforbuild
* Wed Jul 31 2002 hhetter@suse.de
- fix build with scrollkeeper
- initiate scrollkeeper-update
* Thu Jul 25 2002 jordi@suse.de
- updated to version 2.0.2
* Tue Jul 16 2002 hhetter@suse.de
- updated to version 2.0.1, fix descriptions from
  bugzilla.gnome.org:
  [#75861] Deleting a file in use does not prompt for "save" on close
  [#76001] Should not save window geometry on exit
  [#86333] modality problem on info/message box
  [#87265] s/gedit/Text Editor?
* Thu Jun 20 2002 hhetter@suse.de
- don't install schemas while make install
* Wed Jun 19 2002 hhetter@suse.de
- updated to version 2.0.0
* Thu Jun 13 2002 hhetter@suse.de
- supply schema files
* Thu Jun 13 2002 jordi@suse.de
- Updated to version 1.121.1
* Mon Apr 15 2002 hhetter@suse.de
- initial SuSE release
